@@ -22,11 +22,13 @@ class Mongodb:
     CANCELLATION_POLICIES = 'cancellationPolicies'
     DAILY_REPORTS_COLLECTION = 'daily_report'
     OFFERS_COLLECTION = 'offers'
+    OFFERS_CAMPAIGN_COLLECTION = 'offers_campaigns'
     OFFERS_FEEDBACK_COLLECTION = 'offers_feedback'
     OTA_CHANNEL_COLLECTION = 'ota_channel'
     IOT_ROOM_MAPPING = 'iot_room_mapping'
     INTEGRATION_PROPERTY = 'integration_property'
     INTEGRATION_ORG = 'integration_org'
+    OFFERS_TARGETGROUP_COLLECTION = 'offers_targetgroups'
     UPSWING_INTEGRATIONS = 'integrations'
 
 
